# JimuFlow

[English](README_en.md) | 中文

JimuFlow是一款简单易用的跨平台RPA工具，可以在Windows、Linux、MacOS操作系统上开发和运行RPA应用。

当前支持的指令主要有如下几类：

1. 基础指令：包括流程控制、等待、数据处理等。
2. 操作系统指令：包括文件操作、进程管理、剪贴板操作等。
3. 鼠标键盘指令：用于模拟用户操作鼠标和键盘。
4. 数据表格指令：用于操作表格数据，支持Excel、CSV格式。
5. 网页自动化指令，用于操作浏览器和网页，支持Windows、Linux、MacOS操作系统。
6. Windows自动化指令，用于在Windows操作系统中操作窗口程序。

## 演示

![演示视频](docs/zh/manual/demo.gif)

## 安装

请从项目的发布页面下载安装包进行安装，具体请查看[安装文档](docs/zh/manual/install.md)。

## 构建

如果想自己从源代码构建应用，请参考[构建文档](docs/zh/develop/build.md)。

## 开发

请参见[开发文档](docs/zh/develop/index.md)。

## 贡献

你可以通过以下方式参与贡献：

- 提交问题：如果你发现任何问题，请通过GitHub或Gitee的Issues进行反馈。
- 提交PR：如果你希望改进这个项目，请通过GitHub或Gitee的Pull Request进行提交。

## 许可证

这个项目同时使用 GNU 通用公共许可证（GPL）和商业许可证进行授权。

- 在 GPL 许可下，您可以自由使用、修改和分发该软件，但必须公开任何衍生作品的源代码。
- 如果您希望将衍生作品闭源，请联系我们购买商业许可证。

## 联系作者

关于项目代码的问题，可以直接通过GitHub或Gitee的Issues进行反馈。

其他问题，可以通过以下方式联系我。

- 邮箱：[jimuflow@gmail.com](mailto:jimuflow@gmail.com)
